@@ -11,11 +11,11 @@
 
 import logging
 from pathlib import Path
-import textwrap
 from typing import Dict, Optional
 
+
+CONFTEST_LOGGER = logging.getLogger("conftest")
 LOG_FORMAT = "%(asctime)s %(levelname)7s:%(name)s  %(message)s"
-LOG_INDENT = 4
 
 LOGGERS = {
     "conftest": None,
@@ -53,6 +53,10 @@ def avoid_duplicated_logs():
         logging.root.handlers.remove(handler)
 
 
+init_conftest_logger()
+avoid_duplicated_logs()
+
+
 def init_module_logger(system_test_name: str, testdir: Path):
     logger = logging.getLogger(system_test_name)
     logger.handlers.clear()
@@ -78,13 +82,6 @@ def deinit_test_logger():
     LOGGERS["test"] = None
 
 
-def indent_message(msg):
-    lines = msg.splitlines()
-    first = lines[0] + "\n"
-    to_indent = "\n".join(lines[1:])
-    return first + textwrap.indent(to_indent, " " * LOG_INDENT)
-
-
 def log(lvl: int, msg: str, *args, **kwargs):
     """Log message with the most-specific logger currently available."""
     logger = LOGGERS["test"]
@@ -93,8 +90,6 @@ def log(lvl: int, msg: str, *args, **kwargs):
     if logger is None:
         logger = LOGGERS["conftest"]
     assert logger is not None
-    if "\n" in msg:
-        msg = indent_message(msg)
     logger.log(lvl, msg, *args, **kwargs)
 
 
