@@ -156,7 +156,7 @@ typedef struct {
 typedef uint32_t librpz_idx_t;
 #define LIBRPZ_IDX_NULL 0
 #define LIBRPZ_IDX_MIN	1
-#define LIBRPZ_IDX_BAD	((librpz_idx_t)-1)
+#define LIBRPZ_IDX_BAD	((librpz_idx_t) - 1)
 /**
  * Partial decoded results of a set of RPZ queries for a single DNS response
  * or iteration through the mapped file.
@@ -387,9 +387,9 @@ LIBDEF_F(clist_detach)
  * @param use_expired: true to not ignore expired zones
  * @return client handle or NULL if the handle could not be created
  */
-typedef librpz_client_t *(librpz_client_create_t)(librpz_emsg_t	*emsg,
+typedef librpz_client_t *(librpz_client_create_t)(librpz_emsg_t	 *emsg,
 						  librpz_clist_t *clist,
-						  const char     *cstr,
+						  const char	 *cstr,
 						  bool		  use_expired);
 LIBDEF_F(client_create)
 
@@ -486,9 +486,9 @@ LIBDEF_F(have_ns_trig)
  * @param[in,out] rsp state from librpz_itr_start()
  * @return false on error
  */
-typedef bool(librpz_rsp_clientip_prefix_t)(librpz_emsg_t	 *emsg,
+typedef bool(librpz_rsp_clientip_prefix_t)(librpz_emsg_t   *emsg,
 					   librpz_prefix_t *prefix,
-					   librpz_rsp_t	*rsp);
+					   librpz_rsp_t	   *rsp);
 LIBDEF_F(rsp_clientip_prefix)
 
 /**
@@ -501,9 +501,9 @@ LIBDEF_F(rsp_clientip_prefix)
  * @param[in,out] rsp state from librpz_itr_start()
  * @return false on error
  */
-typedef bool(librpz_rsp_domain_t)(librpz_emsg_t	*emsg,
+typedef bool(librpz_rsp_domain_t)(librpz_emsg_t	      *emsg,
 				  librpz_domain_buf_t *owner,
-				  librpz_rsp_t	       *rsp);
+				  librpz_rsp_t	      *rsp);
 LIBDEF_F(rsp_domain)
 
 /**
@@ -759,7 +759,7 @@ typedef socku_t *(librpz_mk_inet_su_t)(socku_t *su, const struct in_addr *addrp,
 				       in_port_t port);
 LIBDEF_F(mk_inet_su)
 
-typedef socku_t *(librpz_mk_inet6_su_t)(socku_t		*su,
+typedef socku_t *(librpz_mk_inet6_su_t)(socku_t		      *su,
 					const struct in6_addr *addrp,
 					uint32_t scope_id, in_port_t port);
 LIBDEF_F(mk_inet6_su)
@@ -782,57 +782,57 @@ LIBDEF(const char *, librpz_dnsrpzd_path)
  * This is the dlopen() interface to librpz.
  */
 typedef const struct {
-	const char			   *dnsrpzd_path;
-	const char			   *version;
-	librpz_parse_log_opt_t	       *parse_log_opt;
-	librpz_log_level_val_t	       *log_level_val;
+	const char			 *dnsrpzd_path;
+	const char			 *version;
+	librpz_parse_log_opt_t		 *parse_log_opt;
+	librpz_log_level_val_t		 *log_level_val;
 	librpz_set_log_t		 *set_log;
-	librpz_vpemsg_t			*vpemsg;
-	librpz_pemsg_t		       *pemsg;
-	librpz_vlog_t		      *vlog;
-	librpz_log_t		     *log;
+	librpz_vpemsg_t			 *vpemsg;
+	librpz_pemsg_t			 *pemsg;
+	librpz_vlog_t			 *vlog;
+	librpz_log_t			 *log;
 	librpz_fatal_t *fatal		  LIBRPZ_NORET;
 	librpz_rpz_assert_t *rpz_assert	  LIBRPZ_NORET;
 	librpz_rpz_vassert_t *rpz_vassert LIBRPZ_NORET;
-	librpz_clist_create_t	      *clist_create;
-	librpz_clist_detach_t	      *clist_detach;
-	librpz_client_create_t	       *client_create;
+	librpz_clist_create_t		 *clist_create;
+	librpz_clist_detach_t		 *clist_detach;
+	librpz_client_create_t		 *client_create;
 	librpz_connect_t		 *connect;
-	librpz_client_detach_t	       *client_detach;
-	librpz_rsp_create_t		    *rsp_create;
-	librpz_rsp_detach_t		    *rsp_detach;
-	librpz_rsp_result_t		    *rsp_result;
-	librpz_have_trig_t		   *have_trig;
-	librpz_have_ns_trig_t	      *have_ns_trig;
-	librpz_rsp_clientip_prefix_t     *rsp_clientip_prefix;
-	librpz_rsp_domain_t		    *rsp_domain;
-	librpz_rsp_rr_t			*rsp_rr;
+	librpz_client_detach_t		 *client_detach;
+	librpz_rsp_create_t		 *rsp_create;
+	librpz_rsp_detach_t		 *rsp_detach;
+	librpz_rsp_result_t		 *rsp_result;
+	librpz_have_trig_t		 *have_trig;
+	librpz_have_ns_trig_t		 *have_ns_trig;
+	librpz_rsp_clientip_prefix_t	 *rsp_clientip_prefix;
+	librpz_rsp_domain_t		 *rsp_domain;
+	librpz_rsp_rr_t			 *rsp_rr;
 	librpz_rsp_soa_t		 *rsp_soa;
-	librpz_soa_serial_t		    *soa_serial;
-	librpz_rsp_push_t		  *rsp_push;
+	librpz_soa_serial_t		 *soa_serial;
+	librpz_rsp_push_t		 *rsp_push;
 	librpz_rsp_pop_t		 *rsp_pop;
 	librpz_rsp_pop_discard_t	 *rsp_pop_discard;
 	librpz_rsp_forget_zone_t	 *rsp_forget_zone;
-	librpz_ck_ip_t		       *ck_ip;
-	librpz_ck_domain_t		   *ck_domain;
-	librpz_zone_refresh_t	      *zone_refresh;
+	librpz_ck_ip_t			 *ck_ip;
+	librpz_ck_domain_t		 *ck_domain;
+	librpz_zone_refresh_t		 *zone_refresh;
 	librpz_db_info_t		 *db_info;
-	librpz_itr_start_t		   *itr_start;
-	librpz_mf_stats_t		  *mf_stats;
-	librpz_vers_stats_t		    *vers_stats;
-	librpz_itr_zone_t		  *itr_zone;
-	librpz_itr_node_t		  *itr_node;
-	librpz_policy2str_t		    *policy2str;
-	librpz_trig2str_t		  *trig2str;
-	librpz_secs2str_t		  *secs2str;
-	librpz_str2secs_t		  *str2secs;
-	librpz_rtype2str_t		   *rtype2str;
-	librpz_domain_ntop_t	     *domain_ntop;
-	librpz_domain_pton2_t	      *domain_pton2;
-	librpz_mk_inet_su_t		    *mk_inet_su;
-	librpz_mk_inet6_su_t	     *mk_inet6_su;
-	librpz_str2su_t			*str2su;
-	librpz_su2str_t			*su2str;
+	librpz_itr_start_t		 *itr_start;
+	librpz_mf_stats_t		 *mf_stats;
+	librpz_vers_stats_t		 *vers_stats;
+	librpz_itr_zone_t		 *itr_zone;
+	librpz_itr_node_t		 *itr_node;
+	librpz_policy2str_t		 *policy2str;
+	librpz_trig2str_t		 *trig2str;
+	librpz_secs2str_t		 *secs2str;
+	librpz_str2secs_t		 *str2secs;
+	librpz_rtype2str_t		 *rtype2str;
+	librpz_domain_ntop_t		 *domain_ntop;
+	librpz_domain_pton2_t		 *domain_pton2;
+	librpz_mk_inet_su_t		 *mk_inet_su;
+	librpz_mk_inet6_su_t		 *mk_inet6_su;
+	librpz_str2su_t			 *str2su;
+	librpz_su2str_t			 *su2str;
 } librpz_0_t;
 extern librpz_0_t librpz_def_0;
 
@@ -844,7 +844,7 @@ extern librpz_0_t librpz_def_0;
 #define LIBRPZ_DEF_STR "librpz_def_0"
 
 typedef librpz_0_t librpz_t;
-extern librpz_t	*librpz;
+extern librpz_t	  *librpz;
 
 #if LIBRPZ_LIB_OPEN == 2
 #include <dlfcn.h>
@@ -858,7 +858,7 @@ extern librpz_t	*librpz;
  */
 static inline librpz_t *
 librpz_lib_open(librpz_emsg_t *emsg, void **dl_handle, const char *path) {
-	void     *handle;
+	void	 *handle;
 	librpz_t *new_librpz;
 
 	emsg->c[0] = '\0';
@@ -870,7 +870,7 @@ librpz_lib_open(librpz_emsg_t *emsg, void **dl_handle, const char *path) {
 		if (dlclose(*dl_handle) != 0) {
 			snprintf(emsg->c, sizeof(librpz_emsg_t),
 				 "dlopen(NULL): %s", dlerror());
-			return (NULL);
+			return NULL;
 		}
 		*dl_handle = NULL;
 	}
@@ -887,39 +887,39 @@ librpz_lib_open(librpz_emsg_t *emsg, void **dl_handle, const char *path) {
 			if (dl_handle != NULL) {
 				*dl_handle = handle;
 			}
-			return (new_librpz);
+			return new_librpz;
 		}
 		if (dlclose(handle) != 0) {
 			snprintf(emsg->c, sizeof(librpz_emsg_t),
 				 "dlsym(NULL, " LIBRPZ_DEF_STR "): %s",
 				 dlerror());
-			return (NULL);
+			return NULL;
 		}
 	}
 
 	if (path == NULL || path[0] == '\0') {
 		snprintf(emsg->c, sizeof(librpz_emsg_t),
 			 "librpz not linked and no dlopen() path provided");
-		return (NULL);
+		return NULL;
 	}
 
 	handle = dlopen(path, RTLD_NOW | RTLD_LOCAL);
 	if (handle == NULL) {
 		snprintf(emsg->c, sizeof(librpz_emsg_t), "dlopen(%s): %s", path,
 			 dlerror());
-		return (NULL);
+		return NULL;
 	}
 	new_librpz = dlsym(handle, LIBRPZ_DEF_STR);
 	if (new_librpz != NULL) {
 		if (dl_handle != NULL) {
 			*dl_handle = handle;
 		}
-		return (new_librpz);
+		return new_librpz;
 	}
 	snprintf(emsg->c, sizeof(librpz_emsg_t),
 		 "dlsym(%s, " LIBRPZ_DEF_STR "): %s", path, dlerror());
 	dlclose(handle);
-	return (NULL);
+	return NULL;
 }
 #elif defined(LIBRPZ_LIB_OPEN)
 /*
@@ -935,11 +935,11 @@ librpz_lib_open(librpz_emsg_t *emsg, void **dl_handle, const char *path) {
 
 #if LIBRPZ_LIB_OPEN == 1
 	emsg->c[0] = '\0';
-	return (&LIBRPZ_DEF);
+	return &LIBRPZ_DEF;
 #else  /* if LIBRPZ_LIB_OPEN == 1 */
 	snprintf(emsg->c, sizeof(librpz_emsg_t),
 		 "librpz not available via ./configure");
-	return (NULL);
+	return NULL;
 #endif /* LIBRPZ_LIB_OPEN */
 }
 #endif /* LIBRPZ_LIB_OPEN */
