@@ -59,12 +59,6 @@
  */
 #define UNUSED(x) (void)(x)
 
-#if __has_c_attribute(maybe_unused)
-#define ISC_ATTR_UNUSED [[maybe_unused]]
-#else
-#define ISC_ATTR_UNUSED __attribute__((__unused__))
-#endif
-
 #if __GNUC__ >= 8 && !defined(__clang__)
 #define ISC_NONSTRING __attribute__((nonstring))
 #else /* if __GNUC__ >= 8 && !defined(__clang__) */
@@ -362,9 +356,9 @@ mock_assert(const int result, const char *const expression,
  * Alignment
  */
 #ifdef __GNUC__
-#define ISC_ALIGN(x, a) (((x) + (a)-1) & ~((typeof(x))(a)-1))
+#define ISC_ALIGN(x, a) (((x) + (a) - 1) & ~((typeof(x))(a) - 1))
 #else /* ifdef __GNUC__ */
-#define ISC_ALIGN(x, a) (((x) + (a)-1) & ~((uintmax_t)(a)-1))
+#define ISC_ALIGN(x, a) (((x) + (a) - 1) & ~((uintmax_t)(a) - 1))
 #endif /* ifdef __GNUC__ */
 
 /*%
